@@ -1,6 +1,6 @@
 /*
- * twclock:  A world clock implemented with Motif widgets
- * Copyright (C) 1997 Ted Williams WA0EIR 
+ * twclock:  A world clock implemented with openMotif widgets
+ * Copyright (C) 1997 - 2004 Ted Williams WA0EIR 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge. MA 02139, USA.
  * See COPYING file in this directory.
  *
- * Version: 2.1 - Mar 2003
+ * Version: 2.3 - Mar 2004
  */
 
 /*
@@ -30,8 +30,8 @@ void  build_widgets ()
 {
    Widget form, separator, popup_menu;
 
-   XmString pop_label, local_label, local_acc_label, gmt_label, gmt_acc_label,
-       others_label, others_acc_label, timer_label, timer_acc_label;
+   XmString xms[15];
+   int i,j;
 
    /*
     * This section creates all of the widgets for the main
@@ -66,7 +66,7 @@ void  build_widgets ()
       XmNrightAttachment, XmATTACH_FORM,
       XmNtopAttachment, XmATTACH_NONE,
       XmNleftAttachment, XmATTACH_FORM,
-      XmNshadowThickness, 8,
+      XmNshadowThickness, 4,
       XmNseparatorType, XmSHADOW_ETCHED_OUT,
       NULL);
 
@@ -99,7 +99,7 @@ void  build_widgets ()
       XmNtopAttachment, XmATTACH_WIDGET,
       XmNtopWidget, call_toggleB,
       XmNmaximum, 23,
-      XmNshowValue, TRUE,
+      XmNshowValue, True,
       NULL);
 
    /*
@@ -119,7 +119,7 @@ void  build_widgets ()
       XmNtopAttachment, XmATTACH_WIDGET,
       XmNtopWidget, call_toggleB,
       XmNmaximum, 59,
-      XmNshowValue, TRUE,
+      XmNshowValue, True,
       NULL);
 
    /*
@@ -136,7 +136,7 @@ void  build_widgets ()
       XmNtopAttachment, XmATTACH_WIDGET,
       XmNtopWidget, call_toggleB,
       XmNmaximum, 59,
-      XmNshowValue, TRUE,
+      XmNshowValue, True,
       NULL);
 
    /*
@@ -147,41 +147,43 @@ void  build_widgets ()
    /*
     * Create the XmStrings for the push buttons
     */
-   pop_label = XmStringCreateLocalized ("Time Zone");
-   local_label = XmStringCreateLocalized ("Local");
-   local_acc_label = XmStringCreateLocalized ("Ctrl-L");
-   gmt_label = XmStringCreateLocalized ("GMT");
-   gmt_acc_label = XmStringCreateLocalized ("Ctrl-G");
-   others_label = XmStringCreateLocalized ("Others");
-   others_acc_label = XmStringCreateLocalized ("Ctrl-O");
-   timer_label = XmStringCreateLocalized ("Set Timer");
-   timer_acc_label= XmStringCreateLocalized ("Ctrl-S");
+
+   i = 0;
+   xms[i] = XmStringCreateLocalized ("Time Zone"); i++;
+   xms[i] = XmStringCreateLocalized ("Local"); i++;
+   xms[i] = XmStringCreateLocalized ("Ctrl-L"); i++;
+   xms[i] = XmStringCreateLocalized ("GMT"); i++;
+   xms[i] = XmStringCreateLocalized ("Ctrl-G"); i++;
+   xms[i] = XmStringCreateLocalized ("Others"); i++;
+   xms[i] = XmStringCreateLocalized ("Ctrl-O"); i++;
+   xms[i] = XmStringCreateLocalized ("Set Timer"); i++;
+   xms[i] = XmStringCreateLocalized ("Ctrl-S"); i++;
+   xms[i] = XmStringCreateLocalized ("QRT"); i++;
+   xms[i] = XmStringCreateLocalized ("Ctrl-Q"); i++;
 
    /*
     * Create popup_menu
     */
+   i = 0;
    popup_menu = XmVaCreateSimplePopupMenu (form, "popup_menu", popup_cb,
-      XmVaTITLE, pop_label,
+      XmVaTITLE, xms[0],
       XmVaSEPARATOR,
-      XmVaPUSHBUTTON, local_label, 'L', "Ctrl<Key>L", local_acc_label,
-      XmVaPUSHBUTTON, gmt_label, 'G', "Ctrl<Key>G", gmt_acc_label,
-      XmVaPUSHBUTTON, others_label, 'O', "Ctrl<Key>O", others_acc_label,
+      XmVaPUSHBUTTON, xms[1], 'L', "Ctrl<Key>L", xms[2],
+      XmVaPUSHBUTTON, xms[3], 'G', "Ctrl<Key>G", xms[4],
+      XmVaPUSHBUTTON, xms[5], 'O', "Ctrl<Key>O", xms[6],
       XmVaSEPARATOR,
-      XmVaPUSHBUTTON, timer_label, 'S', "Ctrl<Key>S", timer_acc_label,
+      XmVaPUSHBUTTON, xms[7], 'S', "Ctrl<Key>S", xms[8],
+      XmVaSEPARATOR,
+      XmVaPUSHBUTTON, xms[9], 'Q', "Ctrl<Key>Q", xms[10],
       NULL);
 
    /*
     * Prevent memory leaks 
     */
-   XmStringFree(pop_label);
-   XmStringFree(local_label);
-   XmStringFree(local_acc_label);
-   XmStringFree(gmt_label);
-   XmStringFree(gmt_acc_label);
-   XmStringFree(others_label);
-   XmStringFree(others_acc_label);
-   XmStringFree(timer_label);
-   XmStringFree(timer_acc_label);
+   for (j=0; j<i; j++)
+   {
+      XmStringFree(xms[j]);
+   }
 
 /*
  * Here the event handler is registered. The default timezone value is
@@ -210,6 +212,7 @@ void  build_widgets ()
 
    XtManageChild(form);
 
+   /*add callbacks */
    XtAddCallback(call_toggleB, XmNvalueChangedCallback,
                  TBchangeCB, (XtPointer)NULL);
 
